@@ -85,15 +85,7 @@ def completed(function_name):
 def aux_logger(in_name: str):
     in_name = in_name.split('.', maxsplit=1)
     in_name = in_name[-1]
-    name_length = len(in_name)
-    if name_length > 33:
-        while name_length > 30:
-            if '.' not in in_name:
-                break
-            in_name = in_name.split('.', maxsplit=1)
-            in_name = in_name[-1]
-            name_length = len(in_name)
-        in_name = '..' + in_name
+
     return logging.getLogger('main.' + in_name)
 
 
@@ -134,25 +126,26 @@ class CustomFormatter(logging.Formatter):
     """
 
     def format(self, record):
+        record.name = record.name.removeprefix('main.')
         if hasattr(record, 'func_name_override'):
             record.funcName = record.func_name_override
         if hasattr(record, 'file_name_override'):
             record.filename = record.file_name_override
-        if len(record.levelname) >= 9:
-            record.levelname = record.levelname[:9 - 3] + '...'
-        if len(record.threadName) >= 14:
-            record.threadName = record.threadName[:14 - 3] + '...'
-        if len(record.name) >= 35:
-            record.name = record.name[:35 - 3] + '...'
-        if len(record.funcName) >= 35:
-            record.funcName = record.funcName[:35 - 3] + '...'
+        if len(record.levelname) >= 11:
+            record.levelname = record.levelname[:11 - 3] + '...'
+        if len(record.threadName) >= 12:
+            record.threadName = record.threadName[-(12 - 3):] + '...'
+        if len(record.name) >= 50:
+            record.name = record.name[-(50 - 3):] + '...'
+        if len(record.funcName) >= 30:
+            record.funcName = record.funcName[:30 - 3] + '...'
 
         return super().format(record)
 
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^13}|{threadName:^14}|{lineno:^7}| {name:<39}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}|{threadName:^12}|{lineno:^5}| {name:<50}|{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
     handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up, maxBytes=10 * (1024 * 1024))
     handler.namer = std_namer
     handler.setFormatter(formatter)
@@ -161,7 +154,7 @@ def _each_run_file_rotate_handler(in_file_name, in_back_up):
 
 def _stdout_handler():
     _date_format = DATEFORMAT_DEV
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^13}| {name:<39}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}| {name:<50}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
     # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
